
SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `alandbUser` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;
USE `alandbUser`;





-- -----------------------------------------------------
-- -----------------------------------------------------
-- -----------------------------------------------------
-- alandbUser
-- -----------------------------------------------------
-- -----------------------------------------------------
-- -----------------------------------------------------


-- -----------------------------------------------------
-- -----------------------------------------------------
-- Powersupplies
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- neue Spalte "channel" bei den Powersupplies (betrifft powersupplies, v_all_powersupplies, v_powersupply, newPowersupply())
-- -----------------------------------------------------
ALTER TABLE `alandbUser`.`powersupplies` ADD COLUMN IF NOT EXISTS `channel` INT(11) NULL DEFAULT NULL AFTER `dummyString1`;


-- -----------------------------------------------------
-- neue Views v_all_powersupplies und v_powersupply
-- -----------------------------------------------------
CREATE OR REPLACE VIEW `v_all_powersupplies` AS SELECT * FROM powersupplies NATURAL JOIN elements;

CREATE OR REPLACE VIEW `v_powersupply` AS
SELECT
	idElements AS id,
	name,
	terminalLoop,
	voltage,
	invert,
	digitalFormat,
	plugID,
	putOnBlock,
	elementID,
	inIsolatorIdIfDirectionPositive,
	outIsolatorIdIfDirectionPositive,
	channel
FROM
	v_all_powersupplies NATURAL JOIN v_sites;


-- -----------------------------------------------------
-- procedure newPowersupply
-- -----------------------------------------------------
DROP PROCEDURE IF EXISTS `alandbUser`.`newPowersupply`;
DELIMITER $$
CREATE PROCEDURE `newPowersupply` (OUT elId INT, IN _plugID INT, IN _elementID INT, IN _name VARCHAR(255), IN _invert INT, IN _terminalLoop INT, IN _putOnBlock INT, IN _channel INT)
BEGIN
DECLARE `_failure` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
SET `_failure` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

START TRANSACTION;
INSERT INTO elements (idElementTypes, idSites) VALUES (8, (SELECT idSites FROM v_sites));
SELECT LAST_INSERT_ID() INTO elId;
INSERT INTO powersupplies (idElements, plugID, terminalLoop, putOnBlock, invert,  elementID, name, channel) VALUES (elId, _plugID, _terminalLoop, _putOnBlock, _invert, _elementID, _name, _channel);

IF `_failure` THEN
	ROLLBACK;
	SET @_idLayer = -1;
	SELECT -1 INTO elId;
	SELECT elId AS 'error';
ELSE
	SELECT elId AS 'id';
	COMMIT;
END IF;

END$$
DELIMITER ;


-- -----------------------------------------------------
-- Die Auswahlmöglichkeit Kehrschleifenblock wird an der Web-Oberfläche nur noch bei
--  'Rein Digital' (pureDigital = 1) und 'Anzahl Gleise' = 2 (middleRail = 0) angezeigt.
-- Im Code wird ein Kehrschleifenblock nur noch bei 'Rein Digital' berücksichtigt.
-- Damit Web-Oberfläche/Code und DB einheitlich sind,
--  wird bei Mischbetrieb terminalLoop auf 0 gesetzt.
-- -----------------------------------------------------
UPDATE alandbUser.powersupplies SET terminalLoop = 0
	WHERE terminalLoop = 1
		AND (SELECT intValue FROM alandbUser.settings WHERE name = 'pureDigital') = 0;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- TrackplanElement
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Spalten hinzufügen
-- -----------------------------------------------------
ALTER TABLE alandbUser.trackplanElements ADD COLUMN IF NOT EXISTS connDelimME INT NULL DEFAULT NULL AFTER y2;
ALTER TABLE alandbUser.trackplanElements ADD COLUMN IF NOT EXISTS connSigME INT NULL DEFAULT NULL AFTER connDelimME;


-- -----------------------------------------------------
-- v_all_trackplanElements mit neuen Spalten neu definieren
-- -----------------------------------------------------
CREATE OR REPLACE VIEW alandbUser.v_all_trackplanElements AS
SELECT
	trackplanElements.idElements AS idElements,
	trackplanElements.idTrackplanElements AS idTrackplanElements,
	trackplanElements.idTrackplanElementTypes AS idTrackplanElementTypes,
	trackplanElements.x AS x,
	trackplanElements.y AS y,
	trackplanElements.z AS z,
	trackplanElements.rot AS rot,
	trackplanElements.idTrackplans AS idTrackplans,
	trackplanElements.itemID AS itemID,
	trackplanElements.idLayers AS idLayers,
	trackplanElements.x2 AS x2,
	trackplanElements.y2 AS y2,
	trackplanElements.connDelimME AS connDelimME,
	trackplanElements.connSigME AS connSigME,
	trackplanElements.dummyInt1 AS dummyInt1,
	trackplanElements.dummyInt2 AS dummyInt2,
	trackplanElements.dummyInt3 AS dummyInt3,
	trackplanElements.dummyInt4 AS dummyInt4,
	trackplanElements.dummyDouble1 AS dummyDouble1,
	trackplanElements.dummyDouble2 AS dummyDouble2,
	trackplanElements.dummyString1 AS dummyString1,
	elements.active AS active,
	elements.visible AS visible,
	elements.idElementTypes AS idElementTypes,
	elements.idSites AS idSites,
	elements.dummyElementInt1 AS dummyElementInt1,
	elements.dummyElementString1 AS dummyElementString1
FROM
	(trackplanElements
	JOIN elements ON ((trackplanElements.idElements = elements.idElements)));


-- -----------------------------------------------------
-- v_all_trackplanElements mit neuen Spalten neu definieren
-- -----------------------------------------------------
CREATE OR REPLACE VIEW alandbUser.v_trackplanElements AS
SELECT
	te.idElements AS id,
	te.idTrackplanElementTypes AS subtype,
	te.x AS x1,
	te.y AS y1,
	te.z AS z1,
	te.x2 AS x2,
	te.y2 AS y2,
	te.rot AS rotation,
	te.itemID AS itemID,
	te.idLayers AS layer,
	te.connDelimME AS connDelimME,
	te.connSigME AS connSigME
FROM
	(v_all_trackplanElements te
	JOIN v_sites ON ((te.idSites = v_sites.idSites)));


-- -----------------------------------------------------
-- procedure removeTrackplanElement
-- Löscht das TrackplanElement mit der ID id
-- -----------------------------------------------------
USE `alandbUser`;
DROP PROCEDURE IF EXISTS `alandbUser`.`removeTrackplanElement`;
DELIMITER $$
USE `alandbUser`$$
CREATE PROCEDURE `removeTrackplanElement` (IN id INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
-- ERROR
SET `_rollback` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

START TRANSACTION;
DELETE FROM trackplanElements WHERE idElements=id;
DELETE FROM elements WHERE idElements=id;

IF `_rollback` THEN
	ROLLBACK;
else
	COMMIT;
END IF;

END$$
DELIMITER ;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- TrackplanMicroElement
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Spalte hinzufügen
-- -----------------------------------------------------
ALTER TABLE alandbUser.trackplanMicroElements ADD COLUMN IF NOT EXISTS connElem INT NULL DEFAULT NULL AFTER idSymbol;


-- -----------------------------------------------------
-- v_all_trackplanMicroElements mit neuer Spalte neu definieren
-- -----------------------------------------------------
CREATE OR REPLACE VIEW alandbUser.v_all_trackplanMicroElements AS
SELECT
	trackplanMicroElements.idElements AS idElements,
	trackplanMicroElements.idtrackplanMicroElements AS idtrackplanMicroElements,
	trackplanMicroElements.x1 AS x1,
	trackplanMicroElements.y1 AS y1,
	trackplanMicroElements.z1 AS z1,
	trackplanMicroElements.x2 AS x2,
	trackplanMicroElements.y2 AS y2,
	trackplanMicroElements.z2 AS z2,
	trackplanMicroElements.x3 AS x3,
	trackplanMicroElements.idTrackplanMicroElementTypes AS idTrackplanMicroElementTypes,
	trackplanMicroElements.itemID AS itemID,
	trackplanMicroElements.idTrackplans AS idTrackplans,
	trackplanMicroElements.rotation AS rotation,
	trackplanMicroElements.distance AS distance,
	trackplanMicroElements.idLayers AS idLayers,
	trackplanMicroElements.idSymbol AS idSymbol,
	trackplanMicroElements.connElem AS connElem,
	trackplanMicroElements.dummyInt1 AS dummyInt1,
	trackplanMicroElements.dummyInt2 AS dummyInt2,
	trackplanMicroElements.dummyint3 AS dummyint3,
	trackplanMicroElements.dummyInt4 AS dummyInt4,
	trackplanMicroElements.dummyString1 AS dummyString1,
	trackplanMicroElements.dummyString2 AS dummyString2,
	elements.active AS active,
	elements.visible AS visible,
	elements.idElementTypes AS idElementTypes,
	elements.idSites AS idSites,
	elements.dummyElementInt1 AS dummyElementInt1,
	elements.dummyElementString1 AS dummyElementString1
FROM
	(trackplanMicroElements
	JOIN elements ON ((trackplanMicroElements.idElements = elements.idElements)));


-- -----------------------------------------------------
-- v_trackplanMicroElements mit neuer Spalte neu definieren
-- -----------------------------------------------------
CREATE OR REPLACE VIEW alandbUser.v_trackplanMicroElements AS
SELECT
	t.idElements AS id,
	t.x1 AS x1,
	t.y1 AS y1,
	t.z1 AS z1,
	t.x2 AS x2,
	t.y2 AS y2,
	t.z2 AS z2,
	t.idTrackplanMicroElementTypes AS subtype,
	t.itemID AS itemID,
	t.rotation AS rotation,
	t.distance AS distance,
	t.idLayers AS layer,
	t.idSymbol AS symbolID,
	t.connElem AS connElem
FROM
	(v_all_trackplanMicroElements t
	JOIN v_sites ON ((t.idSites = v_sites.idSites)));


-- -----------------------------------------------------
-- procedure newTrackplanMicroElement
-- Fügt ein neues TrackplanMicroElement hinzu
-- -----------------------------------------------------
USE alandbUser;
DROP PROCEDURE IF EXISTS alandbUser.newTrackplanMicroElement;
DELIMITER $$
USE alandbUser$$
CREATE PROCEDURE alandbUser.newTrackplanMicroElement(OUT elId INT, IN _subType INT, IN _x1 INT, IN _y1 INT, IN _z1 INT, IN _x2 DOUBLE, IN _y2 DOUBLE, IN _z2 DOUBLE, IN _x3 DOUBLE, IN _rot INT, IN _itemId INT, IN _layerID INT, IN _symbolID VARCHAR(45), IN _connElem INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN

SET `_rollback` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 as RETURNED_SQLSTATE  , @p2 as MESSAGE_TEXT;
END;

START TRANSACTION;
INSERT INTO elements (idElementTypes, idSites) VALUES (6, (SELECT idSites From v_sites));
SELECT LAST_INSERT_ID() INTO elId;
SELECT elId AS 'id';
INSERT INTO trackplanMicroElements(idElements,x1,y1,z1,x2,y2,z2,x3,rotation,itemId,idTrackplanMicroElementTypes,idTrackplans,idLayers,idSymbol,connElem) VALUES(elId,_x1,_y1,_z1,_x2,_y2,_z2,_x3,_rot,_itemId,_subType,(SELECT idTrackplans FROM v_trackplan),_layerId,_symbolID,_connElem);

IF `_rollback` THEN
	ROLLBACK;
	SELECT -1 INTO elId;
else
	COMMIT;
END IF;

END$$
DELIMITER ;


-- -----------------------------------------------------
-- procedure removeTrackplanMicroElement
-- Löscht das TrackplanMicroElement mit der ID id und die damit verbundenen Strecken/Abstände,
-- die in der Tabelle trackMeasurements gespeichert sind. Dazu wird die Prozedur removeMeasurementToId verwendet.
-- Damit wird sichergestellt, dass zuerst die mit dem MicroElement verbundenen Measurements entfernt werden und
-- erst danach das MicroElement gelöscht wird.
-- -----------------------------------------------------
USE `alandbUser`;
DROP PROCEDURE IF EXISTS `alandbUser`.`removeTrackplanMicroElement`;
DELIMITER $$
USE `alandbUser`$$
CREATE PROCEDURE `removeTrackplanMicroElement` (IN id INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION SET `_rollback` = 1;

START TRANSACTION;
call removeMeasurementToId(id);
DELETE FROM trackplanMicroElements WHERE idElements=id;
DELETE FROM elements WHERE idElements=id;

IF `_rollback` THEN
select 1 as 'error';
	ROLLBACK;
else
	COMMIT;
END IF;

END$$
DELIMITER ;


-- -----------------------------------------------------
-- procedure removeMeasurementToId
-- Damit werden die gespeicherten Strecken und Abstände ("Messsungen") gelöscht,
-- die an der übergebenen ID _startEndElementID starten oder enden.
-- -----------------------------------------------------
USE alandbUser;
DROP PROCEDURE IF EXISTS alandbUser.removeMeasurementToId;
DELIMITER $$
USE alandbUser$$
CREATE PROCEDURE alandbUser.removeMeasurementToId (IN _startEndElementID INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE idM INT;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
-- ERROR
SET `_rollback` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

START TRANSACTION;
SET idM=0;
SELECT idElements FROM trackMeasurements WHERE startElement = _startEndElementID LIMIT 1 INTO idM;

WHILE idM != 0 DO
	DELETE FROM trackMeasurements WHERE idElements=idM;
	DELETE FROM elements WHERE idElements=idM;
	SET idM=0;
	SELECT idElements FROM trackMeasurements WHERE startElement = _startEndElementID LIMIT 1 INTO idM;
END WHILE;

SELECT idElements FROM trackMeasurements WHERE endElement = _startEndElementID LIMIT 1 INTO idM;

WHILE idM != 0 DO
	DELETE FROM trackMeasurements WHERE idElements=idM;
	DELETE FROM elements WHERE idElements=idM;
	SET idM=0;
	SELECT idElements FROM trackMeasurements WHERE endElement = _startEndElementID LIMIT 1 INTO idM;
END WHILE;

IF `_rollback` THEN
	ROLLBACK;
else
	COMMIT;
END IF;

END$$
DELIMITER ;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Measurement
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Spalte hinzufügen
-- -----------------------------------------------------
--
ALTER TABLE alandbUser.trackMeasurements ADD COLUMN IF NOT EXISTS manualLength DOUBLE NULL DEFAULT NULL AFTER measuredLength;


-- -----------------------------------------------------
-- Die Hilfsfunktion __convertMeasurdLengthToManualLength__ löschen (falls vorhanden), erstellen, ausführen und wieder löschen.
-- Wenn die Spalte alandbUser.trackMeasurements.measuredLength vorhanden ist:
--	- Konvertierung/Übertragung der Werte von measuredLength [cm] nach manualLength [mm].
--	- Werte in measuredLength werden auf NULL gesetzt.
-- -----------------------------------------------------
--
DROP PROCEDURE IF EXISTS alandbUser.__convertMeasuredLengthToManualLength__;
DELIMITER $$
USE alandbUser$$
CREATE PROCEDURE alandbUser.__convertMeasuredLengthToManualLength__ ()
BEGIN

IF EXISTS ( SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA = "alandbUser" AND TABLE_NAME = "trackMeasurements" AND COLUMN_NAME = "measuredLength" ) THEN
	UPDATE alandbUser.trackMeasurements SET manualLength = measuredLength * 10 WHERE measuredLength > 0;
	UPDATE alandbUser.trackMeasurements SET measuredLength = NULL;
END IF;

END$$
DELIMITER ;

call alandbUser.__convertMeasuredLengthToManualLength__;

DROP PROCEDURE IF EXISTS alandbUser.__convertMeasuredLengthToManualLength__;


-- -----------------------------------------------------
-- Spalten hinzufügen
-- -----------------------------------------------------
--
ALTER TABLE alandbUser.trackMeasurements ADD COLUMN IF NOT EXISTS estimatedLength DOUBLE NULL DEFAULT NULL AFTER calculatedLength;
ALTER TABLE alandbUser.trackMeasurements ADD COLUMN IF NOT EXISTS verticalHeight DOUBLE NULL DEFAULT NULL AFTER estimatedLength;
ALTER TABLE alandbUser.trackMeasurements ADD COLUMN IF NOT EXISTS numberOfElements DOUBLE NULL DEFAULT NULL AFTER verticalHeight;


-- -----------------------------------------------------
-- v_measurement mit passenden Einträgen
-- -----------------------------------------------------
--
CREATE OR REPLACE VIEW alandbUser.v_measurement AS
SELECT
	idElements AS id,
	manualLength AS manLength,
	calculatedLength AS calcLength,
	estimatedLength AS estLength,
	verticalHeight AS vHeight,
	numberOfElements AS numElems,
	startElement AS startElem,
	endElement AS endElem
FROM
	trackMeasurements NATURAL JOIN elements;


-- -----------------------------------------------------
-- Funktion zum Hinzufügen und aktualisieren einer Messung: newTrackMeasurement
-- -----------------------------------------------------
--
DROP PROCEDURE IF EXISTS alandbUser.newTrackMeasurement;
DELIMITER $$
USE alandbUser$$
CREATE PROCEDURE newTrackMeasurement (OUT elId INT, IN _manLength DOUBLE, IN _calcLength DOUBLE, IN _estLength DOUBLE, IN _vHeight DOUBLE, IN _numElems DOUBLE, IN _fromId INT, IN _toId INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
SET `_rollback` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

SELECT id FROM v_measurement WHERE startElem=_fromId AND endElem=_toId INTO elId;

IF elId IS NULL THEN
	SELECT id FROM v_measurement WHERE startElem=_toId AND endElem=_fromId INTO elId;
END IF;

IF elId IS NOT NULL THEN
	UPDATE v_measurement SET manLength=_manLength, calcLength=_calcLength, estLength=_estLength, vHeight=_vHeight, numElems=_numElems, startElem=_fromId, endElem=_toId WHERE id=elId;
ELSE
	START TRANSACTION;
	INSERT INTO elements (idElementTypes, idSites) VALUES (12, (SELECT idSites FROM v_sites));
	SELECT LAST_INSERT_ID() INTO elId;
	INSERT INTO trackMeasurements(idElements,startElement,endElement,manualLength,calculatedLength,estimatedLength,verticalHeight,numberOfElements,idTrackplans) VALUES(elId, _fromId,_toId,_manLength,_calcLength,_estLength,_vHeight,_numElems,(SELECT idTrackplans FROM v_trackplan));

	IF `_rollback` THEN
		ROLLBACK;
		SELECT -1 INTO elId;
	ELSE
		SELECT elId AS 'id';
		COMMIT;
	END IF;
END IF;

END$$
DELIMITER ;


-- -----------------------------------------------------
-- Funktion zum Entfernen einer Messung: removeMeasurement
-- -----------------------------------------------------
--
DROP PROCEDURE IF EXISTS alandbUser.removeMeasurement;
DELIMITER $$
USE alandbUser$$
CREATE PROCEDURE removeMeasurement (IN id INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
-- ERROR
SET `_rollback` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

START TRANSACTION;
DELETE FROM trackMeasurements WHERE idElements=id;
DELETE FROM elements WHERE idElements=id;

IF `_rollback` THEN
	ROLLBACK;
ELSE
	COMMIT;
END IF;

END$$
DELIMITER ;


-- -----------------------------------------------------
-- Die Anzahl an Gleisplan-Elementen auf 0 setzen,
-- damit sie nach dem Update von Neuem bestimmt werden
-- -----------------------------------------------------
--
UPDATE alandbUser.trackMeasurements SET numberOfElements = 0;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Weichen
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- neue Spalten bei Weichen (betrifft turnouts, v_all_turnouts, v_turnouts und newTurnout())
-- -----------------------------------------------------
ALTER TABLE `alandbUser`.`turnouts` ADD COLUMN IF NOT EXISTS `pulsePercentage` INT(3) NULL DEFAULT NULL,  ADD COLUMN IF NOT EXISTS `pulseFrequency` INT(11) NULL DEFAULT NULL  AFTER `pulsePercentage` , ADD COLUMN IF NOT EXISTS `pwmOut` TINYINT(1) NULL DEFAULT NULL  AFTER `pulseFrequency` ;


-- -----------------------------------------------------
-- Views v_all_turnouts und v_turnouts
-- -----------------------------------------------------
CREATE OR REPLACE VIEW `v_all_turnouts` AS SELECT * FROM turnouts NATURAL JOIN elements;

CREATE OR REPLACE VIEW `v_turnouts` AS
SELECT
	idElements AS id,
	name,
	idTurnoutStates AS state,
	idTurnoutTypes AS subtype,
	idTracks AS track,
	active,
	plugID,
	pulseDuration,
	poles,
	invert,
	digitalAddress,
	digitalSlot,
	digitalProtocol,
	elementID,
	pwmOut AS ac,
	pulsePercentage,
	pulseFrequency
FROM
	v_all_turnouts NATURAL JOIN v_sites;


-- -----------------------------------------------------
-- procedure newTurnout
-- -----------------------------------------------------
DROP PROCEDURE IF EXISTS `alandbUser`.`newTurnout`;
DELIMITER $$
USE `alandbUser`$$
CREATE PROCEDURE `newTurnout` (OUT elId INT, IN _name VARCHAR(255), IN _idTurnoutTypes INT, IN _idTracks INT, IN _idStates INT, IN _idPlugs INT, IN _pulseDuration INT, IN _poles INT, IN _invert INT, IN _digitalProtocol INT, IN _digitalSlot INT, IN _digitalAddress INT, IN _elementID INT, IN _ac INT, IN _pulsePercentage INT, IN _pulseFrequency INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
-- ERROR
SET `_rollback` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

START TRANSACTION;
INSERT INTO elements (idElementTypes, idSites) VALUES (1, (SELECT idSites FROM v_sites));
SELECT LAST_INSERT_ID() INTO elId;
INSERT INTO turnouts (idElements, name, idTurnoutTypes, idTracks, idTurnoutStates, plugID, pulseDuration, poles, invert, digitalProtocol, digitalSlot, digitalAddress, elementID, pwmOut, pulsePercentage,  pulseFrequency) VALUES (elId, _name, _idTurnoutTypes, _idTracks,(SELECT turnout_states_id FROM `alandbSystem`.`turnoutTypeStates` WHERE turnout_types_id=_idTurnoutTypes LIMIT 1),_idPlugs, _pulseDuration, _poles, _invert, _digitalProtocol, _digitalSlot, _digitalAddress, _elementID, _ac, _pulsePercentage, _pulseFrequency);

IF NOT `_rollback` THEN
	SELECT elId AS 'id';
	COMMIT;
ELSE
	SELECT -1 INTO elId;
	SELECT elId AS 'error';
	ROLLBACK;
END IF;

END$$
DELIMITER ;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Signale
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- neue Spalte bei Signale (betrifft signals, v_all_signals, v_signals und newSignal())
-- -----------------------------------------------------
ALTER TABLE `alandbUser`.`signals`
CHANGE COLUMN IF EXISTS `idSignalStatesAdvance` `idSignalAdvanceStates`  INT(11),
ADD COLUMN IF NOT EXISTS `idSignalManualStates` INT(11) NULL DEFAULT '0' AFTER `idSignalStates`;


-- -----------------------------------------------------
-- Views v_all_signals und v_signals
-- -----------------------------------------------------
CREATE OR REPLACE VIEW `alandbUser`.`v_all_signals` AS SELECT * FROM signals NATURAL JOIN elements;

CREATE OR REPLACE VIEW `alandbUser`.`v_signals` AS
SELECT
	name,
	idSignalStates AS state,
	idSignalManualStates AS manualState,
	idSignalAdvanceStates AS advanceState,
	idSignalTypes AS subtype,
	idTracks AS track,
	idElements AS id,
	virtual,
	plugID,
	lightType,
	pulseDuration,
	invert,
	voltage,
	current,
	brightness,
	fadeSpeed,
	digitalAddress,
	digitalSlot,
	digitalProtocol,
	elementID
FROM
	v_all_signals NATURAL JOIN v_sites;


-- -----------------------------------------------------
-- Die Funktion newSignal() mit neuem Parameter neu definieren
-- -----------------------------------------------------
DELIMITER $$
DROP PROCEDURE IF EXISTS `alandbUser`.`newSignal`;
USE `alandbUser`$$
CREATE PROCEDURE `newSignal`(OUT elId INT,
	IN _name VARCHAR(255), IN _idSignalTypes INT, IN _idTracks INT, IN _idSignalDesigns INT,
	IN _plugID INT, IN _current INT, IN _brightness INT, IN _fadeSpeed INT, IN _digitalProtocol INT,
	IN _digitalSlot INT, IN _digitalAddress INT, IN _voltage INT, IN _invert INT,
	IN _pulseDuration INT, IN _lightType INT, IN _elementID INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
SET `_rollback` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

START TRANSACTION;
INSERT INTO elements (idElementTypes, idSites) VALUES (3, (SELECT idSites From v_sites));
SELECT LAST_INSERT_ID() INTO elId;
INSERT INTO signals
	(idElements, name, idSignalTypes, idTracks, idSignalDesigns,
		idSignalStates, idSignalManualStates, idSignalAdvanceStates,
		plugID, current, brightness, fadeSpeed, digitalProtocol, digitalSlot, digitalAddress,
		voltage, invert, pulseDuration, lightType, elementID)
VALUES
	(elId, _name, _idSignalTypes, _idTracks, _idSignalDesigns,
		(SELECT idSignalStates FROM `alandbSystem`.`signalTypeStates` WHERE idSignalTypes=_idSignalTypes LIMIT 1), 0, 0,
		_plugID,  _current, _brightness, _fadeSpeed, _digitalProtocol, _digitalSlot, _digitalAddress,
		_voltage, _invert, _pulseDuration, _lightType, _elementID);

IF NOT `_rollback` THEN
	SELECT elId AS 'id';
	COMMIT;
ELSE
	SELECT 0 INTO elId;
	SELECT elId AS 'error';
	ROLLBACK;
END IF;

END$$
DELIMITER ;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Tabelle acCalibration und Prozedur newPlug
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Tabelle acCalibration wird erstellt oder auf den aktuellen Stand gebracht
-- -----------------------------------------------------

-- -----------------------------------------------------
-- Tabelle acCalibration wird erstellt, wenn sie nicht existiert (mit den aktuell gültigen Spalten)
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `alandbUser`.`acCalibration` (
	`idElements` INT(11) NOT NULL,
	`idPlugs` INT(11) NULL DEFAULT NULL,
	`voltage` INT(11) NULL DEFAULT NULL,
	`brickSerial` VARCHAR(16) NULL DEFAULT NULL,
	`acLUT0` INT(11) NULL DEFAULT NULL,
	`acLUT1` INT(11) NULL DEFAULT NULL,
	`acLUT2` INT(11) NULL DEFAULT NULL,
	`acLUT3` INT(11) NULL DEFAULT NULL,
	`acLUT4` INT(11) NULL DEFAULT NULL,
	`acLUT5` INT(11) NULL DEFAULT NULL,
	`acLUT6` INT(11) NULL DEFAULT NULL,
	`acLUT7` INT(11) NULL DEFAULT NULL,
	`acLUT8` INT(11) NULL DEFAULT NULL,
	`acLUT9` INT(11) NULL DEFAULT NULL,
	`acLUT10` INT(11) NULL DEFAULT NULL,
	`idBricks` INT(11) NULL DEFAULT NULL,
	`dummyInt1` INT(11) NULL DEFAULT NULL,
	`dummyInt2` INT(11) NULL DEFAULT NULL,
	`dummyInt3` INT(11) NULL DEFAULT NULL,
	`dummyInt4` INT(11) NULL DEFAULT NULL,
	`dummyString1` VARCHAR(255) NULL DEFAULT NULL,
	`dummyString2` VARCHAR(255) NULL DEFAULT NULL,
	`dummyDouble1` DOUBLE NULL DEFAULT NULL,
	`dummyDouble2` DOUBLE NULL DEFAULT NULL,
	PRIMARY KEY (`idElements`),
	INDEX `fk_acCalibration_2` (`idPlugs` ASC),
	CONSTRAINT `fk_acCalibration_1`
		FOREIGN KEY (`idElements`)
		REFERENCES `alandbUser`.`elements` (`idElements`)
		ON DELETE NO ACTION
		ON UPDATE NO ACTION,
	CONSTRAINT `fk_acCalibration_2`
		FOREIGN KEY (`idPlugs`)
		REFERENCES `alandbUser`.`elements` (`idElements`)
		ON DELETE NO ACTION
		ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- wenn die Tabelle bereits existiert, wird sie aktualisiert
-- -----------------------------------------------------
ALTER TABLE `alandbUser`.`acCalibration` ADD COLUMN IF NOT EXISTS `voltage` INT(11) NULL DEFAULT NULL  AFTER `idPlugs`;
ALTER TABLE `alandbUser`.`acCalibration` ADD COLUMN IF NOT EXISTS `brickSerial` VARCHAR(16) NULL DEFAULT NULL  AFTER `voltage`;
ALTER TABLE `alandbUser`.`acCalibration` CHANGE COLUMN IF EXISTS `idAcCalibration` `idElements` INT(11) NOT NULL;
ALTER TABLE `alandbUser`.`acCalibration` ADD CONSTRAINT `fk_acCalibration_1` FOREIGN KEY IF NOT EXISTS (`idElements` )  REFERENCES `alandbUser`.`elements` (`idElements` )  ON DELETE NO ACTION  ON UPDATE NO ACTION;
ALTER TABLE `alandbUser`.`acCalibration` ADD CONSTRAINT `fk_acCalibration_2` FOREIGN KEY IF NOT EXISTS (`idPlugs` )  REFERENCES `alandbUser`.`elements` (`idElements` )  ON DELETE NO ACTION  ON UPDATE NO ACTION;


-- -----------------------------------------------------
-- Kalibrierung wird in die Liste der elementTypes hinzugefügt
-- -----------------------------------------------------
INSERT IGNORE INTO `alandbSystem`.`elementTypes` (`idElementTypes`, `viewName`, `description`, `tableName`) VALUES (20, 'v_calibrations', 'Kalibrierungsn', 'acCalibration');


-- -----------------------------------------------------
-- View wird dazu erstellt (v_calibrations)
-- -----------------------------------------------------
CREATE OR REPLACE VIEW `alandbUser`.`v_calibrations` AS
SELECT
	idElements AS id,
	idPlugs AS plugID,
	brickSerial,
	voltage,
	acLUT0,
	acLUT1,
	acLUT2,
	acLUT3,
	acLUT4,
	acLUT5,
	acLUT6,
	acLUT7,
	acLUT8,
	acLUT9,
	acLUT10
FROM
	acCalibration NATURAL JOIN elements;


-- -----------------------------------------------------
-- Funktion newCalibration wird erstellt
-- -----------------------------------------------------
DELIMITER $$
DROP PROCEDURE IF EXISTS `alandbUser`.`newCalibration`;
$$CREATE PROCEDURE `alandbUser`.`newCalibration` (OUT elId INT,  IN _plugID INT, IN _brickSerial VARCHAR(16), IN _voltage INT, IN _acLUT0 INT, IN _acLUT1 INT, IN _acLUT2 INT, IN _acLUT3 INT, IN _acLUT4 INT, IN _acLUT5 INT, IN _acLUT6 INT, IN _acLUT7 INT, IN _acLUT8 INT, IN _acLUT9 INT, IN _acLUT10 INT)
BEGIN
DECLARE `_failure` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
-- ERROR
SET `_failure` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

START TRANSACTION;
INSERT INTO elements (idElementTypes, idSites) VALUES (20, (SELECT idSites From v_sites));
SELECT LAST_INSERT_ID() INTO elId;
INSERT INTO acCalibration (idElements, idPlugs, brickSerial, voltage, acLUT0, acLUT1, acLUT2, acLUT3, acLUT4, acLUT5, acLUT6, acLUT7, acLUT8, acLUT9, acLUT10) VALUES (elId, _plugID, _brickSerial, _voltage, _acLUT0, _acLUT1, _acLUT2, _acLUT3, _acLUT4, _acLUT5, _acLUT6, _acLUT7, _acLUT8, _acLUT9, _acLUT10);

IF `_failure` THEN
	ROLLBACK;
	SET @a = -1;
	SELECT -1 INTO elId;
	SELECT elId AS 'error';
ELSE
	SELECT elId AS 'id';
	COMMIT;
END IF;

END$$


-- -----------------------------------------------------
-- procedure removeCalibration
-- -----------------------------------------------------
DELIMITER $$
DROP PROCEDURE IF EXISTS `alandbUser`.`removeCalibration`;
$$CREATE PROCEDURE `alandbUser`.`removeCalibration` (IN id INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
-- ERROR CASE
SET `_rollback` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

START TRANSACTION;
DELETE FROM acCalibration WHERE idElements=id;
DELETE FROM elements WHERE idElements=id;

IF `_rollback` THEN
	ROLLBACK;
else
	COMMIT;
END IF;

END$$


-- -----------------------------------------------------
-- procedure removePlug wird mit Berücksichtigung der acCalibration-Tabelle neu definiert
-- -----------------------------------------------------
DELIMITER $$
DROP PROCEDURE IF EXISTS `alandbUser`.`removePlug`;
$$CREATE PROCEDURE `removePlug` (IN id INT)
BEGIN
DECLARE idC INT;
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION SET `_rollback` = 1;

START TRANSACTION;
SELECT idElements FROM acCalibration WHERE idPlugs = id  LIMIT 1 INTO idC;

WHILE idC != 0 DO
	DELETE FROM acCalibration WHERE idElements=idC;
	DELETE FROM elements WHERE idElements=idC;
	SET idC=0;
	SELECT idElements FROM acCalibration WHERE idPlugs = id LIMIT 1 INTO idC;
END WHILE;

DELETE FROM plugs WHERE idElements=id;
DELETE FROM elements WHERE idElements=id;

IF `_rollback` THEN
	ROLLBACK;
	SELECT 1 AS Error;
else
	COMMIT;
END IF;

END$$
DELIMITER ;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Plugs
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Der Datentyp der Spalte serialNumber wird vergrößert (betrifft Tabelle alandbUser.plugs und procedure newPlug)
-- -----------------------------------------------------
ALTER TABLE `alandbUser`.`plugs` CHANGE COLUMN `serialNumber` `serialNumber` VARCHAR(21) NULL DEFAULT '0000000000000000';


-- -----------------------------------------------------
-- Spalte connectedPlug hinzufügen (betrifft Tabelle alandbUser.plugs und View v_plug)
-- Darin wird bei MUC-AC und BRIDGE-ACH gespeichert, mit welcher BRIDGE-ACH bzw. MUX sie gemeinsam genutzt werden.
-- -----------------------------------------------------
ALTER TABLE alandbUser.plugs ADD COLUMN IF NOT EXISTS connectedPlug INT(11) NULL DEFAULT NULL AFTER subSubtype;


-- -----------------------------------------------------
-- View v_plug
-- -----------------------------------------------------
CREATE OR REPLACE VIEW alandbUser.v_plug AS
SELECT
	p.idElements AS id,
	p.idPlugTypes AS subtype,
	p.channel AS channel,
	el.active AS active,
	p.subSubtype AS subSubtype,
	p.name AS name,
	p.serialNumber AS serialNumber,
	p.connectedPlug AS connectedPlug,
	p.additionalParameters AS additionalParameters,
	ep.itemNumber AS itemNumber,
	ep.licenseKey AS licenseKey,
	ep.manufacturerPrimary AS manufacturerPrimary,
	ep.manufacturerSecondary AS manufacturerSecondary,
	ep.itemNumberSecondary AS itemNumberSecondary,
	ep.itemShortDescription AS itemShortDescription,
	ep.itemSubtype AS itemSubtype,
	ep.itemType AS itemType,
	ep.preconfigurable AS preconfigurable,
	ep.numConfigUpdates AS numConfigUpdates,
	ep.configReserve AS configReserve,
	ep.hwRevision AS hwRevision,
	ep.psuVoltage AS psuVoltage,
	ep.psuPower AS psuPower,
	ep.manufacturerData AS manufacturerData,
	ep.timeFactorMinVal AS timeFactorMinVal,
	ep.timeFactorMinExp AS timeFactorMinExp,
	ep.timeFactorMaxVal AS timeFactorMaxVal,
	ep.timeFactorMaxExp AS timeFactorMaxExp,
	ep.symbolID AS symbolID,
	ep.dummyInt1 AS dummyInt1,
	ep.dummyInt2 AS dummyInt2,
	ep.dummyInt3 AS dummyInt3,
	ep.dummyString1 AS dummyString1,
	ep.dummyDouble1 AS dummyDouble1
FROM
	((plugs p
	JOIN elements el ON ((el.idElements = p.idElements)))
	JOIN eeproms ep ON ((ep.itemNumber = p.itemNumber)));


-- -----------------------------------------------------
-- procedure newPlug
-- -----------------------------------------------------
USE `alandbUser`;
DROP PROCEDURE IF EXISTS `alandbUser`.`newPlug`;
DELIMITER $$
USE `alandbUser`$$
CREATE PROCEDURE `newPlug`(OUT elId INT, IN _serialNumber VARCHAR(21), IN _plugType INT, IN _channel INT, IN _subSubtype VARCHAR(45), IN _itemNumber INT, IN _itemType INT, IN _itemSubtype INT)
BEGIN
DECLARE `_failure` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION SET `_failure` = 1;

START TRANSACTION;

IF NOT EXISTS (SELECT * FROM eeproms WHERE itemNumber = _itemNumber) THEN
	INSERT INTO eeproms (itemNumber, itemType, itemSubtype) VALUES (_itemNumber, _itemType, _itemSubtype);
END IF;

INSERT INTO elements (idElementTypes, idSites) VALUES (17, (SELECT idSites FROM v_sites));
SELECT LAST_INSERT_ID() INTO elId;
SELECT elId AS 'id';
INSERT INTO plugs (idElements, serialNumber, idPlugTypes, channel, subSubtype, itemNumber, name) VALUES (elId, _serialNumber, _plugType, _channel, _subSubtype, _itemNumber, (SELECT itemShortDescription FROM eeproms WHERE itemNumber = _itemNumber));

IF `_failure` THEN
	ROLLBACK;
	SELECT 1 AS Fehler;
ELSE
	COMMIT;
END IF;

END$$
DELIMITER ;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Zubehör
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Zubehör-Parameter zum Blinken und Faden
-- -----------------------------------------------------

-- -----------------------------------------------------
-- Neue Spalten in der accessory-Tabelle
-- -----------------------------------------------------
ALTER TABLE `alandbUser`.`accessories`
DROP COLUMN if EXISTS `fadeSpeed`,
ADD COLUMN IF NOT EXISTS `brightnessUpper` INT(11) NULL DEFAULT NULL AFTER `brightness`,
ADD COLUMN IF NOT EXISTS  `brightnessLower` INT(11) NULL DEFAULT NULL AFTER `brightnessUpper`,
ADD COLUMN IF NOT EXISTS  `mode` INT(11) NULL DEFAULT NULL AFTER `brightnessLower`,
ADD COLUMN IF NOT EXISTS  `fadeUpOnce` DOUBLE NULL DEFAULT NULL AFTER `mode`,
ADD COLUMN IF NOT EXISTS  `fadeDownOnce` DOUBLE NULL DEFAULT NULL AFTER `fadeUpOnce`,
ADD COLUMN IF NOT EXISTS  `fadeUpPer` INT(11) NULL DEFAULT NULL AFTER `fadeDownOnce`,
ADD COLUMN IF NOT EXISTS  `fadeDownPer` INT(11) NULL DEFAULT NULL AFTER `fadeUpPer`,
ADD COLUMN IF NOT EXISTS  `period` DOUBLE NULL DEFAULT NULL AFTER `fadeDownPer`,
ADD COLUMN IF NOT EXISTS  `pulse` INT(11) NULL DEFAULT NULL AFTER `period`;


-- -----------------------------------------------------
-- Views v_all_accessories und v_accessory mit neuen Spalten neu initialisieren
-- -----------------------------------------------------
CREATE OR REPLACE VIEW `alandbUser`.`v_all_accessories` AS select * FROM accessories NATURAL JOIN elements;

CREATE OR REPLACE VIEW `alandbUser`.`v_accessory` AS
SELECT
	name,
	idAccessoryStates AS state,
	idAccessoryTypes AS subtype,
	idElements AS id,
	active,
	idPlugs AS plugID,
	brightness,
	brightnessUpper,
	brightnessLower,
	mode,
	fadeUpOnce,
	fadeDownOnce,
	fadeUpPer,
	fadeDownPer,
	period,
	pulse,
	channel,
	pwm,
	current,
	voltage,
	pulseDuration,
	speed,
	digitalProtocol,
	digitalAddress,
	digitalSlot,
	elementID
FROM
	v_all_accessories NATURAL JOIN v_sites;


-- -----------------------------------------------------
-- Die Funktion newAccessory() mit neuen Parametern neu definieren
-- -----------------------------------------------------
DELIMITER $$
DROP PROCEDURE IF EXISTS `alandbUser`.`newAccessory`;
$$CREATE PROCEDURE `newAccessory`(OUT elId INT, IN _name VARCHAR(255), IN _idAccessoryTypes INT, IN _idTracks INT, IN _plugID INT,  IN _current INT, IN _brightness INT, IN _brightnessUpper INT, IN _brightnessLower INT, IN _mode INT, IN _fadeUpOnce DOUBLE, IN _fadeDownOnce DOUBLE, IN _fadeUpPer INT, IN _fadeDownPer INT, IN _period DOUBLE, IN _pulse INT, IN _channel INT, IN _speed INT, IN _digitalProtocol INT, IN _digitalSlot INT, IN _digitalAddress INT, IN _elementID INT, IN _voltage INT, IN _pwm INT, IN _pulseDuration INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
SET `_rollback` = 1;
END;

START TRANSACTION;
INSERT INTO elements (idElementTypes, idSites) VALUES (4, (SELECT idSites FROM v_sites));
SELECT LAST_INSERT_ID() INTO elId;
INSERT INTO accessories (idElements, name, idAccessoryTypes, idTracks, idPlugs, idAccessoryStates, current, brightness, brightnessUpper, brightnessLower, mode, fadeUpOnce, fadeDownOnce, fadeUpPer, fadeDownPer, period, pulse, channel, speed, digitalProtocol, digitalSlot, digitalAddress, elementID, voltage, pwm, pulseDuration ) VALUES (elId, _name, _idAccessoryTypes, _idTracks, _plugID, (SELECT idAccessoryStates FROM `alandbSystem`.`accessoryTypestates` WHERE idAccessoryTypes=_idAccessoryTypes LIMIT 1),  _current, _brightness, _brightnessUpper, _brightnessLower, _mode, _fadeUpOnce, _fadeDownOnce, _fadeUpPer, _fadeDownPer, _period, _pulse, _channel, _speed, _digitalProtocol, _digitalSlot, _digitalAddress, _elementID, _voltage, _pwm, _pulseDuration );

IF NOT `_rollback` THEN
	SELECT elId AS 'id';
	COMMIT;
ELSE
	SELECT 0 INTO elId;
	SELECT elId AS 'error';
	ROLLBACK;
END IF;

END$$
DELIMITER ;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Trains
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Spalten hinzufügen
-- -----------------------------------------------------
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS vMRwSAt1kmh DOUBLE NULL DEFAULT NULL AFTER maxDeceleration;
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS pwmAt1kmh INT NULL DEFAULT NULL AFTER vMRwSAt1kmh;
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS vMRwSAtSpeedMax DOUBLE NULL DEFAULT NULL AFTER pwmAt1kmh;
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS pwmAtSpeedMax INT NULL DEFAULT NULL AFTER vMRwSAtSpeedMax;
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS segmentID INT NULL DEFAULT NULL AFTER isSet;
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS lastBlockLocalID INT NULL DEFAULT NULL AFTER segmentID;
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS distTPosToNextDelim DOUBLE NULL DEFAULT NULL AFTER nextIsolatorId;
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS signalSpeedLimit DOUBLE NULL DEFAULT NULL AFTER direction;
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS startTrSegElemID INT NULL DEFAULT NULL AFTER signalSpeedLimit;
ALTER TABLE alandbUser.trains ADD COLUMN IF NOT EXISTS endTrSegElemID INT NULL DEFAULT NULL AFTER startTrSegElemID;


-- -----------------------------------------------------
-- Hinzugefügte (neue) Spalten bei Bedarf initialisieren
-- -----------------------------------------------------
--
-- Für bereits aufgesetzte Züge soll die SegmentID 1 verwendet werden. Gültig bei allen Gleisplänen, die aus nur einem
-- Segment bestehen. Bei anderen Gleisplänen konnten beim Neustart bisher schon nicht alle Züge korrekt aufgesetzt
-- werden.
--
UPDATE alandbUser.trains SET segmentID = 1 WHERE segmentID IS NULL AND lastBlockLocalID > 0;



-- -----------------------------------------------------
-- v_train mit neuen Spalten neu definieren
-- -----------------------------------------------------
CREATE OR REPLACE VIEW `alandbUser`.`v_train` AS
SELECT
	`el`.`id` AS `id`,
	`alandbUser`.`trains`.`name` AS `name`,
	`alandbUser`.`trains`.`idTrainTypes` AS `subtype`,
	`el`.`active` AS `active`,
	`alandbUser`.`trains`.`maxAcceleration` AS `maxAcceleration`,
	`alandbUser`.`trains`.`maxDeceleration` AS `maxDeceleration`,
	`alandbUser`.`trains`.`vMRwSAt1kmh` AS `vMRwSAt1kmh`,
	`alandbUser`.`trains`.`pwmAt1kmh` AS `pwmAt1kmh`,
	`alandbUser`.`trains`.`vMRwSAtSpeedMax` AS `vMRwSAtSpeedMax`,
	`alandbUser`.`trains`.`pwmAtSpeedMax` AS `pwmAtSpeedMax`,
	`alandbUser`.`trains`.`trainMembers` AS `trainMembers`,
	`alandbUser`.`trains`.`x1` AS `x1`,
	`alandbUser`.`trains`.`y1` AS `y1`,
	`alandbUser`.`trains`.`z1` AS `layer`,
	`alandbUser`.`trains`.`isSet` AS `isSet`,
	`alandbUser`.`trains`.`segmentID` AS `segmentID`,
	`alandbUser`.`trains`.`lastBlockLocalID` AS `lastBlockLocalID`,
	`alandbUser`.`trains`.`nextIsolatorId` AS `nextIsolatorId`,
	`alandbUser`.`trains`.`distTPosToNextDelim` AS `distTPosToNextDelim`,
	`alandbUser`.`trains`.`direction` AS `direction`,
	`alandbUser`.`trains`.`signalSpeedLimit` AS `signalSpeedLimit`,
	`alandbUser`.`trains`.`startTrSegElemID` AS `startTrSegElemID`,
	`alandbUser`.`trains`.`endTrSegElemID` AS `endTrSegElemID`
FROM
	(`alandbUser`.`trains`
		JOIN `alandbUser`.`v_elements` `el` ON ((`alandbUser`.`trains`.`idElements` = `el`.`id`)));
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Rollings
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Werte anpassen
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Jedes vorhandene Fahrzeug (Lokomotive, Wagen) soll eine Länge > 0 besitzen, damit keine Züge mit
-- einer Länge von 0 existieren.
UPDATE alandbUser.rollings SET length = 1 WHERE length <= 0;
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Locomotives
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Spalten hinzufügen
-- -----------------------------------------------------
ALTER TABLE alandbUser.locomotives ADD COLUMN IF NOT EXISTS useKickStart BOOLEAN NULL DEFAULT FALSE AFTER speedIntStart;


-- -----------------------------------------------------
-- v_locomotive mit neuen Spalten neu definieren
-- -----------------------------------------------------
CREATE OR REPLACE VIEW `alandbUser`.`v_locomotive` AS
SELECT
	`rollings`.`idElements` AS `id`,
	`locomotives`.`name` AS `name`,
	`rollings`.`idTracks` AS `track`,
	`locomotives`.`speedMax` AS `speedMax`,
	`locomotives`.`idLocomotiveTypes` AS `subtype`,
	`elements`.`active` AS `active`,
	`locomotives`.`speedIntMin` AS `speedIntMin`,
	`locomotives`.`speedIntMax` AS `speedIntMax`,
	`locomotives`.`speedIntStart` AS `speedIntStart`,
	`locomotives`.`useKickStart` AS `useKickStart`,
	`locomotives`.`direction` AS `direction`,
	`rollings`.`idDecoderTypes` AS `decoderType`,
	`rollings`.`address` AS `address`,
	`rollings`.`length` AS `length`,
	`rollings`.`speedSteps` AS `speedSteps`,
	`decoders`.`idDecoders` AS `idDecoders`,
	`decoders`.`idDecoderTypes` AS `idDecoderTypes`,
	`decoders`.`decoderAddress` AS `decoderAddress`,
	`decoders`.`decoderSpeedSteps` AS `decoderSpeedSteps`,
	`decoders`.`switchFunctions` AS `switchFunctions`,
	`decoders`.`activeFunctions` AS `activeFunctions`,
	`decoders`.`f1Icon` AS `f1Icon`,
	`decoders`.`f1Name` AS `f1Name`,
	`decoders`.`f2Icon` AS `f2Icon`,
	`decoders`.`f2Name` AS `f2Name`,
	`decoders`.`f3Icon` AS `f3Icon`,
	`decoders`.`f3Name` AS `f3Name`,
	`decoders`.`f4Icon` AS `f4Icon`,
	`decoders`.`f4Name` AS `f4Name`,
	`decoders`.`f5Icon` AS `f5Icon`,
	`decoders`.`f5Name` AS `f5Name`,
	`decoders`.`f6Icon` AS `f6Icon`,
	`decoders`.`f6Name` AS `f6Name`,
	`decoders`.`f7Icon` AS `f7Icon`,
	`decoders`.`f7Name` AS `f7Name`,
	`decoders`.`f8Icon` AS `f8Icon`,
	`decoders`.`f8Name` AS `f8Name`,
	`decoders`.`f9Icon` AS `f9Icon`,
	`decoders`.`f9Name` AS `f9Name`,
	`decoders`.`f10Icon` AS `f10Icon`,
	`decoders`.`f10Name` AS `f10Name`,
	`decoders`.`f11Icon` AS `f11Icon`,
	`decoders`.`f11Name` AS `f11Name`,
	`decoders`.`f12Icon` AS `f12Icon`,
	`decoders`.`f12Name` AS `f12Name`,
	`decoders`.`f13Icon` AS `f13Icon`,
	`decoders`.`f13Name` AS `f13Name`,
	`decoders`.`f14Icon` AS `f14Icon`,
	`decoders`.`f14Name` AS `f14Name`,
	`decoders`.`f15Icon` AS `f15Icon`,
	`decoders`.`f15Name` AS `f15Name`,
	`decoders`.`f16Icon` AS `f16Icon`,
	`decoders`.`f16Name` AS `f16Name`,
	`decoders`.`f17Icon` AS `f17Icon`,
	`decoders`.`f17Name` AS `f17Name`,
	`decoders`.`f18Icon` AS `f18Icon`,
	`decoders`.`f18Name` AS `f18Name`,
	`decoders`.`f19Icon` AS `f19Icon`,
	`decoders`.`f19Name` AS `f19Name`,
	`decoders`.`f20Icon` AS `f20Icon`,
	`decoders`.`f20Name` AS `f20Name`,
	`decoders`.`f21Icon` AS `f21Icon`,
	`decoders`.`f21Name` AS `f21Name`,
	`decoders`.`f22Icon` AS `f22Icon`,
	`decoders`.`f22Name` AS `f22Name`,
	`decoders`.`f23Icon` AS `f23Icon`,
	`decoders`.`f23Name` AS `f23Name`,
	`decoders`.`f24Icon` AS `f24Icon`,
	`decoders`.`f24Name` AS `f24Name`,
	`decoders`.`f25Icon` AS `f25Icon`,
	`decoders`.`f25Name` AS `f25Name`,
	`decoders`.`f26Icon` AS `f26Icon`,
	`decoders`.`f26Name` AS `f26Name`,
	`decoders`.`f27Icon` AS `f27Icon`,
	`decoders`.`f27Name` AS `f27Name`,
	`decoders`.`f28Icon` AS `f28Icon`,
	`decoders`.`f28Name` AS `f28Name`,
	`decoders`.`f29Icon` AS `f29Icon`,
	`decoders`.`f29Name` AS `f29Name`,
	`decoders`.`f30Icon` AS `f30Icon`,
	`decoders`.`f30Name` AS `f30Name`,
	`decoders`.`f31Icon` AS `f31Icon`,
	`decoders`.`f31Name` AS `f31Name`,
	`decoders`.`f32Icon` AS `f32Icon`,
	`decoders`.`f32Name` AS `f32Name`
FROM
	(((`rollings`
	JOIN `elements` ON ((`rollings`.`idElements` = `elements`.`idElements`)))
	JOIN `locomotives` ON ((`locomotives`.`idRollings` = `rollings`.`idRollings`)))
	JOIN `decoders` ON ((`rollings`.`idDecoders` = `decoders`.`idDecoders`)));


-- -----------------------------------------------------
-- procedure newLocomotive
-- -----------------------------------------------------
USE `alandbUser`;
DELIMITER $$
DROP PROCEDURE IF EXISTS `alandbUser`.`newLocomotive`;
$$
CREATE PROCEDURE `alandbUser`.`newLocomotive`(OUT elId INT, IN _name VARCHAR(255), IN _idTracks INT, IN _length DOUBLE, IN _speedMax INT, IN _speedIntMin INT, IN _speedIntMax INT, IN _speedIntStart INT, IN _useKickStart BOOLEAN, IN _idLocomotiveTypes INT, IN _speedLimit INT, IN _direction INT)
BEGIN
DECLARE `_failure` BOOL DEFAULT 0;
DECLARE rollID INT DEFAULT 0;
DECLARE decoderID INT DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION SET `_failure` = 1;

START TRANSACTION;

INSERT INTO elements (idElementTypes, idSites) VALUES (2, (SELECT idSites From v_sites));
SELECT LAST_INSERT_ID() INTO elId;
SELECT elId AS 'id';
INSERT INTO decoders (idDecoderTypes) VALUES (7);
SELECT LAST_INSERT_ID() INTO decoderID;
SELECT decoderID as 'decoderID';
INSERT INTO rollings (idElements, idTracks, idDecoders, length) VALUES (elId, _idTracks, decoderID, _length);
SELECT LAST_INSERT_ID() INTO rollID;
SELECT rollID as 'rollID';
INSERT INTO locomotives (idRollings, name, speedMax, speedIntMin, speedIntMax, speedIntStart, useKickStart, idLocomotiveTypes, speedLimit, direction) VALUES (rollID, _name, _speedMax, _speedIntMin, _speedIntMax, _speedIntStart, _useKickStart, _idLocomotiveTypes, _speedLimit, _direction);
SELECT elID AS id;

IF `_failure` THEN
	ROLLBACK;
	SET @a = -1;
ELSE
	COMMIT;
END IF;

END$$
DELIMITER ;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Decoders
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -------------------------------------
-- Hilfsfunktion zum Anpassen des Defaults der Spalten f1Icon bis f32Icon und Initialisieren der Icons der Funktionen,
-- denen bisher kein Icon zugwiesen wurde.
-- Die Hilfsfunktion __updDefaultIniDigiFncIcons__ löschen (falls vorhanden), erstellen, ausführen und wieder löschen.
-- Beispiel für die Spalte f1Icon:
-- ALTER TABLE alandbUser.decoders CHANGE COLUMN f1Icon f1Icon INT(11) NULL DEFAULT 1000;
-- UPDATE alandbUser.decoders SET f1Icon = 1000 WHERE f1Icon = 0 OR f1Icon IS NULL;
-- -------------------------------------
---
DROP PROCEDURE IF EXISTS alandbUser.__updDefaultIniDigiFncIcons__;
DELIMITER $$
USE alandbUser$$
CREATE PROCEDURE alandbUser.__updDefaultIniDigiFncIcons__ ()
BEGIN

DECLARE colDef INT DEFAULT NULL;

SELECT COLUMN_DEFAULT FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA = "alandbUser" AND TABLE_NAME = "decoders" AND COLUMN_NAME = "f1Icon" INTO colDef;

IF colDef = 0 OR colDef IS NULL THEN
	SET @num = 0;

	WHILE @num < 32 DO
		SET @col = CONCAT("f", CAST(@num + 1 AS CHAR), "Icon");
		SET @iNum = CONCAT(CAST(1000 + @num AS CHAR));

		-- Default anpassen
		SET @statement1 = CONCAT("ALTER TABLE alandbUser.decoders CHANGE COLUMN ", @col, " ", @col, " INT(11) NULL DEFAULT ", @iNum, ";");
		PREPARE stmnt1 FROM @statement1;
		EXECUTE stmnt1;

		-- Icon initialisieren
		SET @statement2 = CONCAT("UPDATE alandbUser.decoders SET ", @col, " = ", @iNum, " WHERE ", @col, " = 0 OR ", @col, " IS NULL;");
		PREPARE stmnt2 FROM @statement2;
		EXECUTE stmnt2;

		SET @num = @num + 1;
	END WHILE;
END IF;

END$$
DELIMITER ;

call alandbUser.__updDefaultIniDigiFncIcons__;

DROP PROCEDURE IF EXISTS alandbUser.__updDefaultIniDigiFncIcons__;
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Settings (alandbSystem und alandbUser)
-- -----------------------------------------------------
-- -----------------------------------------------------
-- -----------------------------------------------------

-- -----------------------------------------------------
-- Funktion zum Übernehmen von neuen Einstellungen: newSetting
-- -----------------------------------------------------
--
USE `alandbUser`;
DELIMITER $$
DROP PROCEDURE IF EXISTS `alandbUser`.`newSetting`;
$$
CREATE PROCEDURE `newSetting`(OUT elID INT, IN _idSettingSubtypes INT )
BEGIN
DECLARE `_failure` BOOL DEFAULT 0;
DECLARE rollID INT DEFAULT 0;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION SET `_failure` = 1;

IF NOT EXISTS (SELECT `idSettingSubtypes` FROM `alandbUser`.`settings` WHERE `idSettingSubtypes` = `_idSettingSubtypes`) THEN
	START TRANSACTION;
	INSERT INTO elements (idElementTypes, idSites) VALUES (19, (SELECT idSites FROM v_sites));
	SELECT LAST_INSERT_ID() INTO elId;
	SELECT name FROM `alandbSystem`.`settingSubtypes` WHERE idSettingSubtypes=_idSettingSubtypes LIMIT 1;
	INSERT INTO settings (idElements, name, idSettingSubtypes) VALUES (elID, (SELECT name FROM `alandbSystem`.`settingSubtypes` WHERE idSettingSubtypes=_idSettingSubtypes LIMIT 1), _idSettingSubtypes);

	IF `_failure` THEN
		ROLLBACK;
		SET @a = -1;
		SELECT -1 INTO elId;
		SELECT elId AS 'error';
	ELSE
		SELECT elId AS 'id';
		COMMIT;
	END IF;
END IF;

END
$$
DELIMITER ;
--
-- -----------------------------------------------------


-- -----------------------------------------------------
-- Funktion zum Löschen eines Settings aus alandbUser.settings: removeSetting
-- -----
-- Als Parameter ist idSettingSubtypes aus alandbSystem.settingSubtypes anzugeben.
-- Damit muss idElements bestimmt werden, um das Setting auch aus alandbUser.elements löschen zu können.
-- -----------------------------------------------------
--
USE alandbUser;
DROP PROCEDURE IF EXISTS alandbUser.removeSetting;
DELIMITER $$
USE alandbUser$$
CREATE PROCEDURE alandbUser.removeSetting (IN _idSettingSubtypes INT)
BEGIN
DECLARE `_rollback` BOOL DEFAULT 0;
DECLARE tmpElID INT;
DECLARE CONTINUE HANDLER FOR SQLEXCEPTION
BEGIN
-- ERROR
SET `_rollback` = 1;
GET DIAGNOSTICS CONDITION 1
@p1 = RETURNED_SQLSTATE, @p2 = MESSAGE_TEXT;
SELECT @p1 AS RETURNED_SQLSTATE, @p2 AS MESSAGE_TEXT;
END;

START TRANSACTION;
SET tmpElID = 0;
SELECT idElements FROM settings WHERE idSettingSubtypes = _idSettingSubtypes INTO tmpElID;

IF tmpElID != 0 THEN
	DELETE FROM settings WHERE idElements = tmpElID;
	DELETE FROM elements WHERE idElements = tmpElID;
END IF;

IF `_rollback` THEN
	ROLLBACK;
else
	COMMIT;
END IF;

END$$
DELIMITER ;
--
-- -----------------------------------------------------


-- -----------------------------------------------------
--  Neue Bedienkarte
-- -----------------------------------------------------
--
-- CV-Editor in Systemeinstellungen
INSERT IGNORE INTO `alandbSystem`.`settingTypes` (`idSettingTypes`, `name`) VALUES (11, 'CV_Editor');
--
-- -----------------------------------------------------


-- -----------------------------------------------------
-- in der alandbSystem bereits definierte Einstellungen werden für den Benutzer sichtbar gemacht
-- -----------------------------------------------------
--
CALL newSetting(@a, 14);
CALL newSetting(@a, 16);
--
-- -----------------------------------------------------


-- -----------------------------------------------------
-- Neue Einstellungen
-- -----------------------------------------------------
--
-- Alle Stecker unter Sonstiges anzeigen
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (52, 'showPlugs', 10, 6, 2, 1, 1, 31, NULL);
CALL newSetting(@a, 52);

--
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (53, 'occACThOffset', 10, 1, 7, 1, 1, 115, 0);
CALL newSetting(@a, 53);

--
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (54, 'occACThMultiplicator', 10, 1, 7, 1, 1, 116, 0);
CALL newSetting(@a, 54);

-- Aufgeschlitzte Weichen schalten
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (56, 'autoCorrectTurnouts', 13, 6, 7, 1, 1, 40, 0);
CALL newSetting(@a, 56);

-- Ein-/Ausblenden von Signalbildern bei Lichtsignalen
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (57, 'signalFadeEnabled', 13, 6, 7, 1, 1, 120, 0);
CALL newSetting(@a, 57);
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (58, 'signalFadeIn', 11, 2, 7, 1, 1, 121, 0);
CALL newSetting(@a, 58);
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (59, 'signalFadeOut', 11, 2, 7, 1, 1, 122, 0);
CALL newSetting(@a, 59);
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (60, 'signalFadeWait', 11, 2, 7, 1, 1, 123, 0);
CALL newSetting(@a, 60);

-- Signaliserung belegter Blöcke
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (61, 'signalBlockStateNotificationEnabled', 13, 6, 7, 1, 0, 130, 0);
CALL newSetting(@a, 61);

-- Offset beim Ermitteln von MM-Digital-Adressen, der zum Stromwert bei ausgeschaltetem Motor addiert wird
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (62, 'offsetMMAddrDetect', 10, 2, 7, 1, 1, 37, 0);
CALL newSetting(@a, 62);

-- Strombegrenzungseinstellungen ein-/ausblenden
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (63, 'curLimitSettingsVisible', 10, 6, 7, 1, 1, 140, 0);
CALL newSetting(@a, 63);

-- PWM-Frequenz bei DC
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (64, 'dcPwmFrequency', 10, 6, 7, 1, 1, 141, 0);
CALL newSetting(@a, 64);

-- BRICK-M: Strombegrenzung
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (65, 'ocurLimitBrickM', 10, 6, 7, 1, 1, 142, 0);
CALL newSetting(@a, 65);

-- BRICK-H: Strombegrenzung
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (66, 'ocurLimitBrickH', 10, 6, 7, 1, 1, 143, 0);
CALL newSetting(@a, 66);

-- Zeit nach Überstromerkennung bis Begrenzung auf eingestelltes BRICK-Limit
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (67, 'ocurDlyLimit', 10, 2, 7, 1, 1, 144, 0);
CALL newSetting(@a, 67);

-- Zeit nach Überstrombegrenzung bis Abschaltung H-Brücke
INSERT IGNORE INTO `alandbSystem`.`settingSubtypes` (`idSettingSubtypes`, `name`, `idParameterTypes`, `idControlTypes`, `idSettingTypes`, `protected`, `live`, `orderIndex`, `isPassword`) VALUES (68, 'ocurDlyStopHBridge', 10, 2, 7, 1, 1, 145, 0);
CALL newSetting(@a, 68);
--
-- -----------------------------------------------------


-- -----------------------------------------------------
-- Hinzugefügte (neue) Einstellungen initialisieren
-- -----------------------------------------------------
--
-- Ein-/Ausblenden von Signalbildern
UPDATE alandbUser.settings SET doubleValue=0.4 WHERE name='signalFadeIn' AND doubleValue IS NULL;
UPDATE alandbUser.settings SET doubleValue=0.4 WHERE name='signalFadeOut' AND doubleValue IS NULL;
UPDATE alandbUser.settings SET doubleValue=0.2 WHERE name='signalFadeWait' AND doubleValue IS NULL;

-- Offset beim Ermitteln von MM-Digital-Adressen
UPDATE alandbUser.settings SET intValue=16 WHERE name='offsetMMAddrDetect' AND intValue IS NULL;

-- Strombegrenzungseinstellungen
-- Die Einstellung curLimitSettingsVisible wird nicht initialisert. Der Default 'NULL' wird vom DatabaseManager als 0
--  interpretiert.
UPDATE alandbUser.settings SET intValue=25000 WHERE name='dcPwmFrequency' AND intValue IS NULL;
UPDATE alandbUser.settings SET intValue=5 WHERE name='ocurDlyLimit' AND intValue IS NULL;
UPDATE alandbUser.settings SET intValue=5 WHERE name='ocurDlyStopHBridge' AND intValue IS NULL;
-- doubleValue zurücksetzen, da es nicht verwendet wird.
UPDATE alandbUser.settings SET doubleValue=NULL WHERE name='ocurDlyLimit' AND doubleValue IS NOT NULL;
UPDATE alandbUser.settings SET doubleValue=NULL WHERE name='ocurDlyStopHBridge' AND doubleValue IS NOT NULL;

-- -------------------------------------
-- Hilfsfunktion zum Initialiseren neuer Einstellungen, die von weiteren Einstellungen abhängig sind.
-- Die Hilfsfunktion __initializeNewSettings__ löschen (falls vorhanden), erstellen, ausführen und wieder löschen.
-- -------------------------------------
---
DROP PROCEDURE IF EXISTS alandbUser.__initializeNewSettings__;
DELIMITER $$
USE alandbUser$$
CREATE PROCEDURE alandbUser.__initializeNewSettings__ ()
BEGIN

DECLARE ocurLimitBrick_M INT DEFAULT NULL;
DECLARE ocurLimitBrick_H INT DEFAULT NULL;
DECLARE pureDigital INT DEFAULT 0;
DECLARE middleRail INT DEFAULT 0;
DECLARE trackType INT DEFAULT 0;

SELECT intValue FROM alandbUser.settings WHERE name='ocurLimitBrickM' INTO ocurLimitBrick_M;
SELECT intValue FROM alandbUser.settings WHERE name='ocurLimitBrickH' INTO ocurLimitBrick_H;

IF ocurLimitBrick_M IS NULL OR ocurLimitBrick_H IS NULL THEN
	-- Einer der beiden Werte ist nicht gesetzt
	SELECT intValue FROM alandbUser.settings WHERE name='pureDigital' INTO pureDigital;
	SELECT intValue FROM alandbUser.settings WHERE name='middleRail' INTO middleRail;

	IF pureDigital > 0 OR middleRail > 0 THEN
		-- 'Rein Digital' oder AC-Mischbetrieb: Maximalwerte des BRICKs
		UPDATE alandbUser.settings SET intValue=1200 WHERE name='ocurLimitBrickM';
		UPDATE alandbUser.settings SET intValue=5200 WHERE name='ocurLimitBrickH';
	ELSE
		-- DC-Mischbetrieb
		SELECT intValue FROM alandbUser.settings WHERE name='track' INTO trackType;

		CASE trackType
			WHEN 1 THEN
				-- Spurweite Z
				UPDATE alandbUser.settings SET intValue=250 WHERE name='ocurLimitBrickM';
				UPDATE alandbUser.settings SET intValue=1500 WHERE name='ocurLimitBrickH';
			WHEN 2 THEN
				-- Spurweite N
				UPDATE alandbUser.settings SET intValue=500 WHERE name='ocurLimitBrickM';
				UPDATE alandbUser.settings SET intValue=1500 WHERE name='ocurLimitBrickH';
			WHEN 3 THEN
				-- Spurweite TT
				UPDATE alandbUser.settings SET intValue=750 WHERE name='ocurLimitBrickM';
				UPDATE alandbUser.settings SET intValue=1500 WHERE name='ocurLimitBrickH';
			WHEN 4 THEN
				-- Spurweite H0
				UPDATE alandbUser.settings SET intValue=1200 WHERE name='ocurLimitBrickM';
				UPDATE alandbUser.settings SET intValue=1500 WHERE name='ocurLimitBrickH';
			WHEN 5 THEN
				-- Spurweite 0
				UPDATE alandbUser.settings SET intValue=1200 WHERE name='ocurLimitBrickM';
				UPDATE alandbUser.settings SET intValue=3000 WHERE name='ocurLimitBrickH';
			WHEN 6 THEN
				-- Spurweite 1
				UPDATE alandbUser.settings SET intValue=1200 WHERE name='ocurLimitBrickM';
				UPDATE alandbUser.settings SET intValue=5200 WHERE name='ocurLimitBrickH';
			WHEN 7 THEN
				-- Spurweite G
				UPDATE alandbUser.settings SET intValue=1200 WHERE name='ocurLimitBrickM';
				UPDATE alandbUser.settings SET intValue=5200 WHERE name='ocurLimitBrickH';
			ELSE
				-- Unknown (Setzen der Werte für Spurweite Z)
				UPDATE alandbUser.settings SET intValue=250 WHERE name='ocurLimitBrickM';
				UPDATE alandbUser.settings SET intValue=1500 WHERE name='ocurLimitBrickH';
		END CASE;
	END IF;
END IF;

END$$
DELIMITER ;

call alandbUser.__initializeNewSettings__;

DROP PROCEDURE IF EXISTS alandbUser.__initializeNewSettings__;
--
-- -------------------------------------
---
-- -----------------------------------------------------


-- -----------------------------------------------------
-- Erkennungsschwellen werden angepasst
-- -----------------------------------------------------
--
-- Bis v1.0.6.0 wurde occDCThStop auf 6 gesetzt, danach auf 60. Damit alle Versionen auf den
-- richtigen Default gesetzt werden, muss auf <=6 geprüft werden.
-- Ist ein Wert <=6 eingestellt, wird er durch ein Update oder Einspielen einer Datensicherung
-- wieder auf 60 gesetzt.
UPDATE alandbUser.settings SET intValue=60 WHERE name='occDCThStop' AND (intValue <= 6 OR intValue IS NULL);

UPDATE alandbUser.settings SET intValue=15 WHERE name='occDigiTh' AND (intValue < 1 OR intValue IS NULL);
UPDATE alandbUser.settings SET intValue=10 WHERE name='occACThOffset' AND (intValue < 1 OR intValue IS NULL);
UPDATE alandbUser.settings SET intValue=110 WHERE name='occACThMultiplicator' AND (intValue < 100 OR intValue IS NULL);
--
-- -----------------------------------------------------


-- -----------------------------------------------------
-- Einstellungen werden live gemacht
-- -----------------------------------------------------
--
UPDATE alandbSystem.settingSubtypes SET live=1 WHERE name='pureDigital';
UPDATE alandbSystem.settingSubtypes SET live=1 WHERE name='middleRail';
UPDATE alandbSystem.settingSubtypes SET live=1 WHERE name='digitalProtocolMM2';
--
-- -----------------------------------------------------


-- -----------------------------------------------------
-- Einstellungen werden nicht mehr live gemacht
-- -----------------------------------------------------
--
UPDATE alandbSystem.settingSubtypes SET live=0 WHERE name='backupStart';
UPDATE alandbSystem.settingSubtypes SET live=0 WHERE name='restoreStart';
UPDATE alandbSystem.settingSubtypes SET live=0 WHERE name='updateStart';
UPDATE alandbSystem.settingSubtypes SET live=0 WHERE name='showPlugs';
--
-- -----------------------------------------------------


-- -----------------------------------------------------
-- Einstellungen auf einen definierten Wert setzen.
-- Werte werden durch ALAN nicht mehr geändert, damit der Select immer den nicht aktivierten Zustand anzeigt.
-- -----------------------------------------------------
--
UPDATE alandbUser.settings SET intValue=0 WHERE name='resetDCDirections';
UPDATE alandbUser.settings SET intValue=0 WHERE name='backupStart';
UPDATE alandbUser.settings SET intValue=0 WHERE name='restoreStart';
UPDATE alandbUser.settings SET intValue=0 WHERE name='updateStart';
--
-- -----------------------------------------------------


-- -----------------------------------------------------
-- selectValues für Select der Systemeinstellungen entfernen, die die Defaultwerte Ja/Nein aus SettingsView::view()
-- verwenden können.
-- -----------------------------------------------------
--
DELETE FROM alandbSystem.selectValues WHERE alias="Ja" OR alias="NEIN";
--
-- -----------------------------------------------------


-- -----------------------------------------------------
-- Bisher verwendete Settings entfernen.
-- Damit sind sie in dem Systemeinstellungen nicht mehr sichtbar,
-- bleiben aber in alandbSystem.settingSubtypes erhalten.
-- -----------------------------------------------------
--
-- dccAckThreshold
CALL removeSetting(43);

--occDCThDrive
CALL removeSetting(49);
--
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- -----------------------------------------------------
-- alandbSystem
-- -----------------------------------------------------
-- -----------------------------------------------------
-- -----------------------------------------------------


-- -----------------------------------------------------
-- -----------------------------------------------------
-- Züge/Lokomotiven/Waggons
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- locomotiveTypes
-- -----------------------------------------------------
INSERT INTO alandbSystem.locomotiveTypes VALUES (4,'Personenwagen') ON DUPLICATE KEY UPDATE name='Personenwagen';
INSERT INTO alandbSystem.locomotiveTypes VALUES (5,'Gueterwagen') ON DUPLICATE KEY UPDATE name='Gueterwagen';
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Steckertypen
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Data for table `alandbSystem`.`plugTypes`; Tabelleninhalt wird komplett neu erstellt
-- -----------------------------------------------------
DELETE FROM `alandbSystem`.`plugTypes`;
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (0, 'Unbekannt');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (1, 'BRIDGE-02L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (2, 'BRIDGE-02M');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (3, 'BRIDGE-02H');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (4, 'BRIDGE-ACH');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (5, 'PowerSupply');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (6, 'Sensor');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (7, 'Accessory');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (8, 'Gleis');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (9, 'Weiche');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (10, 'Signal');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (11, 'BOX');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (12, 'BRIDGE-12L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (13, 'BRIDGE-07L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (14, 'Digitalbus');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (15, 'BRIDGE-03L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (16, 'BRIDGE-04L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (17, 'BRIDGE-04M');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (18, 'BRIDGE-VML');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (19, 'BRIDGE-R2M');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (20, 'BRIDGE-R3L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (21, 'BRIDGE-K2M');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (22, 'BRIDGE-K3L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (23, 'BRIDGE-54L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (24, 'MUX');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (25, 'BRICK_ECO');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (26, 'CON');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (27, 'CON-04L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (28, 'CON-06L');
INSERT INTO `alandbSystem`.`plugTypes` (`idPlugTypes`, `name`) VALUES (29, 'CON-10L');
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Weichen und Streckentypen
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- Data for table `alandbSystem`.`trackplanElementTypes`; Tabelleninhalt wird komplett neu erstellt
-- -----------------------------------------------------
DELETE FROM `alandbSystem`.`trackplanElementTypes`;
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (0, 'unknown');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (1, '2-way-left');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (2, '2-way-right');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (3, '3-way');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (4, 'crossing');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (5, 'straight');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (6, 'curve-45');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (7, 'curve-90');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (8, 'crossing-fixed');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (9, 'bumper');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (10, 'level');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (11, 'Hosenträgerweiche');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (12, 'Y-Weiche');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (13, 'Bogenweiche rechts');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (14, 'Bogenweiche links');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (15, 'Brücke gerade');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (16, 'Brücke 45°-Kurve');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (17, 'Brücke 90°-Kurve');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (18, 'Brücke Anfang/Ende');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (19, 'Tunnel Anfang/Ende');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (20, 'Gleiswechsel links');
INSERT INTO `alandbSystem`.`trackplanElementTypes` (`idTrackplanElementTypes`, `name`) VALUES (21, 'Gleiswechsel rechts');


-- -----------------------------------------------------
-- Weichenstellungen
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Data for table `alandbSystem`.`turnoutTypeStates`; Tabelleninhalt wird komplett neu erstellt
-- -----------------------------------------------------
DELETE FROM `alandbSystem`.`turnoutTypeStates`;
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (1, 1, 1);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (1, 3, 2);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (2, 2, 3);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (2, 3, 4);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (3, 1, 5);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (3, 2, 6);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (3, 3, 7);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (4, 3, 8);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (4, 4, 9);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (11, 3, 10);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (11, 4, 11);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (12, 1, 12);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (12, 2, 13);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (13, 2, 14);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (13, 3, 15);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (14, 1, 16);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (14, 3, 17);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (20, 1, 18);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (20, 3, 19);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (21, 2, 20);
INSERT INTO `alandbSystem`.`turnoutTypeStates` (`turnout_types_id`, `turnout_states_id`, `idturnout_typestates`) VALUES (21, 3, 21);


-- -----------------------------------------------------
-- Verbindungslinien
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Data for table `alandbSystem`.`gridElementConnectionLines`; Tabelleninhalt wird komplett neu erstellt
-- -----------------------------------------------------
DELETE FROM `alandbSystem`.`gridElementConnectionLines`;
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (1, 1, 2, 7, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (2, 1, 2, 8, 1);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (3, 2, 2, 7, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (4, 2, 2, 6, 2);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (5, 3, 2, 7, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (6, 3, 2, 8, 1);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (7, 3, 2, 6, 2);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (8, 4, 2, 7, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (9, 4, 3, 6, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (10, 4, 2, 6, 4);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (11, 4, 3, 7, 4);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (12, 5, 2, 7, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (13, 6, 2, 6, 4);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (14, 7, 2, 4, 4);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (15, 8, 2, 7, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (16, 8, 1, 8, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (17, 9, 2, 9, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (18, 11, 10, 12, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (19, 11, 11, 13, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (20, 11, 10, 13, 4);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (21, 11, 11, 12, 4);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (22, 12, 2, 6, 2);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (23, 12, 2, 8, 1);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (24, 13, 2, 4, 2);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (25, 13, 2, 6, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (26, 14, 2, 5, 1);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (27, 14, 2, 8, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (28, 15, 2, 7, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (29, 16, 2, 6, 4);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (30, 17, 2, 4, 4);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (31, 18, 2, 7, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (32, 19, 2, 7, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (33, 20, 10, 13, 1);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (34, 20, 10, 12, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (35, 20, 11, 13, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (36, 21, 11, 12, 2);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (37, 21, 10, 12, 3);
INSERT INTO `alandbSystem`.`gridElementConnectionLines` (`idgridElementConnectionLines`, `turnout_types_idturnout_types`, `gridConnectionPoints_idgridConnectionPoints`, `gridConnectionPoints_idgridConnectionPoints1`, `turnout_states_idturnout_states`) VALUES (38, 21, 11, 13, 3);
--
-- -----------------------------------------------------
-- -----------------------------------------------------





-- -----------------------------------------------------
-- -----------------------------------------------------
-- Signale
-- -----------------------------------------------------
-- -----------------------------------------------------
--
-- -----------------------------------------------------
-- signalStates
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Data for table `alandbSystem`.`signalStates`; Tabelleninhalt wird komplett neu erstellt
-- -----------------------------------------------------
DELETE FROM `alandbSystem`.`signalStates`;
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (0, 'undef', 'Nicht definiert');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (1, 'hp0 oder fb0', 'Halt');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (2, 'hp1 oder fb1', 'Fahrt');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (3, 'hp2', 'Langsamfahrt');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (4, 'vr0', 'Halt erwarten');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (5, 'vr1', 'Fahrt erwarten');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (6, 'vr2', 'Langsamfahrt erwarten');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (7, 'off', 'Aus');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (8, 'ch_fb2', 'Höchstgeschwindigkeit 40');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (9, 'ch_fb3', 'Höchstgeschwindigkeit 60');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (10, 'ch_fb4', 'Höchstgeschwindigkeit 90');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (11, 'ch_fb5', 'Höchstgeschwindigkeit 90');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (12, 'ch_fb6', 'Höchstgeschwindigkeit 40, Halt erwarten');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (13, 'sh1', 'Rangiersignal Fahrt');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (14, 'sh0', 'Rangiersignal Stop');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (15, 'hp0+sh1', 'Kombi RangierFahrt');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (16, 'Hp0 Notrot', 'Notrot');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (17, 'on/rot', 'Rot/Blinkend');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (18, 's50', 'Höchstgeschwindigkeit 50');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (19, 's70', 'Höchstgeschwindigkeit 70');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (20, 's80', 'Höchstgeschwindigkeit 80');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (21, 'P', 'Pfeifen');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (22, 's20', 'Höchstgeschwindigkeit 20');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (23, 's10', 'Höchstgeschwindigkeit 10');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (24, 's30', 'Höchstgeschwindigkeit 30');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (25, 's40', 'Höchstgeschwindigkeit 40');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (26, 's60', 'Höchstgeschwindigkeit 60');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (27, 's90', 'Höchstgeschwindigkeit 90');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (28, 's100', 'Höchstgeschwindigkeit 100');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (29, 's110', 'Höchstgeschwindigkeit 110');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (30, 's120', 'Höchstgeschwindigkeit 120');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (31, 'hl1', 'Freie Fahrt: V_max,  dann V_max');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (32, 'hl2', '100 km/h, dann V_max');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (33, 'hl3a', '40 km/h, dann V_max');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (34, 'hl3b', '60 km/h, dann V_max');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (35, 'hl4', 'V_max, dann 100 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (36, 'hl5', '100 km/h, dann 100 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (37, 'hl6a', '40 km/h, dann 100 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (38, 'hl6b', '60 km/h, dann 100 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (39, 'hl7', 'V_max, dann 40/60 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (40, 'hl8', '100 km/h, dann 40/60 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (41, 'hl9a', '40 km/h, dann 40/60 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (42, 'hl9b', '60 km/h, dann 40/60 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (43, 'hl10', 'Halt erwarten');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (44, 'hl11', '100 km/h, dann Halt erwarten');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (45, 'hl12a', '40 km/h, dann Halt erwarten');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (46, 'hl12b', '60 km/h, dann Halt erwarten');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (47, 'hl13', 'Halt');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (48, 'hl13ra12', 'Halt (Rangiersignal)');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (49, 'hl13zs1', 'Halt (Ersatzsignal)');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (50, 'ch_v_fb1', 'Ankündigung Freie Fahrt');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (51, 'ch_v_fb2', 'Geschwindigkeits-Ankündigung 40 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (52, 'ch_v_fb3', 'Geschwindigkeits-Ankündigung 60 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (53, 'ch_v_fb5', 'Geschwindigkeits-Ankündigung 90 km/h');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (54, 'ch_warnung', 'Warnung (Hauptsignal zeigt Halt)');
INSERT INTO `alandbSystem`.`signalStates` (`idSignalStates`, `name`, `description`) VALUES (55, 'bumper', 'Prellbock 0 km/h');



-- -----------------------------------------------------
-- Signaltypen
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Data for table `alandbSystem`.`signalTypes`; Tabelleninhalt wird komplett neu erstellt
-- -----------------------------------------------------
DELETE FROM `alandbSystem`.`signalTypes`;
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (1, 'Hauptsignal 1');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (2, 'Hauptsignal 2');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (3, 'Vorsignal');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (4, 'Sperrsignal Scheibe');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (5, 'Sperrsignal Ampel');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (6, 'Ausfahrsignal 1');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (7, 'Ausfahrsignal 2');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (8, 'Lichtblocksignal 1');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (9, 'Lichtblocksignal 2');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (10, 'Licht-Einfahrsignal 1');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (11, 'Licht-Einfahrsignal 2');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (12, 'Licht-Einfahrsignal 3');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (13, 'Licht-Einfahrsignal 4');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (14, 'DB-Vorsignal');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (15, 'Bahnübergangssignal Neue Bundesländer');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (16, 'Bahnübergangssignal Alte Bundesländer');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (17, 'Geschwindigkeitstafel 10');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (18, 'Geschwindigkeitstafel 20');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (19, 'Geschwindigkeitstafel 30');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (20, 'Geschwindigkeitstafel 40');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (21, 'Geschwindigkeitstafel 50');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (22, 'Geschwindigkeitstafel 60');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (23, 'Geschwindigkeitstafel 70');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (24, 'Geschwindigkeitstafel 80');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (25, 'Geschwindigkeitstafel 90');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (26, 'Geschwindigkeitstafel Ende');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (27, 'Signaltafel P');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (28, 'Geschwindigkeitstafel 100');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (29, 'Geschwindigkeitstafel 110');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (30, 'Geschwindigkeitstafel 120');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (31, 'Geschwindigkeitstafel 0 km/h Prellbock');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (50, 'Schweizer Zwergsignal');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (51, 'Schweizer Hauptsignal 1');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (52, 'Schweizer Hauptsignal 2');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (53, 'Schweizer Hauptsignal 3');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (54, 'Schweizer Hauptsignal 4');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (55, 'Schweizer Hauptsignal mit Vorsignal 1');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (56, 'Schweizer Hauptsignal mit Vorsignal 2');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (57, 'Schweizer Hauptsignal mit Vorsignal 3');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (58, 'Schweizer Hauptsignal mit Vorsignal 4');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (59, 'Schweizer Vorsignal');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (80, 'DR Hl Hauptsig, 3-begriffig');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (81, 'DR Hl Hauptsig, 5-begriffig');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (82, 'DR Hl Hauptsig, 9-begriffig');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (83, 'DR Hl Hauptsig mit Ra12, 11-begriffig');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (84, 'DR Hl Hauptsig mit Ra12, 11-begr. Ersatzrot');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (85, 'DR Hl Hauptsig mit ge Lichtstr, 13-begr');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (86, 'DR Hl Hauptsig mit gr Lichtstr, 13-begr');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (87, 'DR Hl Hauptsig mit ge/gr Lichtstr 17-begr');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (88, 'DR Hl Blocksignal, 3-begriffig');
INSERT INTO `alandbSystem`.`signalTypes` (`idSignalTypes`, `name`) VALUES (89, 'DR Hl Vorsignal, 4-begriffig');


-- -----------------------------------------------------
-- Zuordnung von signal_State zu signal_Type
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Data for table `alandbSystem`.`signalTypeStates`; Tabelleninhalt wird komplett neu erstellt
-- -----------------------------------------------------
DELETE FROM `alandbSystem`.`signalTypeStates`;
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 1, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 1, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 2, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 2, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 2, 3);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 3, 4);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 3, 5);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 3, 6);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 4, 13);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 4, 14);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 5, 13);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 5, 14);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 6, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 6, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 6, 3);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 6, 15);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 7, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 7, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 7, 3);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 7, 15);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 8, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 8, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 9, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 9, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 10, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 10, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 10, 3);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 11, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 11, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 11, 3);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 12, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 12, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 12, 3);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 12, 16);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 13, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 13, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 13, 3);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 13, 16);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 14, 4);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 14, 5);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 14, 6);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 15, 7);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 15, 17);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 16, 7);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 16, 17);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 17, 23);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 18, 22);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 19, 24);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 20, 25);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 21, 18);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 22, 26);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 23, 19);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 24, 20);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 25, 27);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 26, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 27, 21);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 28, 28);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 29, 29);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 30, 30);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 31, 55);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 50, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 50, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 50, 3);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 51, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 51, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 52, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 52, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 52, 8);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 53, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 53, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 53, 8);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 53, 9);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 54, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 54, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 54, 8);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 54, 9);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 54, 10);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 54, 12);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 55, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 55, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 56, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 56, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 56, 8);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 57, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 57, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 57, 8);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 57, 9);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 58, 1);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 58, 2);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 58, 8);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 58, 9);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 58, 10);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 58, 12);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 59, 50);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 59, 51);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 59, 52);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 59, 54);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 80, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 80, 47);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 81, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 81, 33);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 81, 47);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 82, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 82, 33);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 82, 43);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 82, 47);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 83, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 83, 33);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 83, 43);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 83, 47);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 84, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 84, 33);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 84, 43);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 84, 47);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 85, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 85, 33);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 85, 34);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 85, 43);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 85, 47);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 86, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 86, 32);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 86, 33);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 86, 43);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 86, 47);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 87, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 87, 32);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 87, 33);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 87, 34);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 87, 43);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 87, 47);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 88, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 88, 47);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 89, 31);
INSERT INTO `alandbSystem`.`signalTypeStates` (`idSignalTypeStates`, `idSignalTypes`, `idSignalStates`) VALUES (NULL, 89, 43);
--
-- -----------------------------------------------------
-- -----------------------------------------------------



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
